Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Function register_target_provider_endpoints

pub async fn register_target_provider_endpoints<R: RpcServer, T: DeploymentTarget + 'static>(
    rpc_server: &R,
    deployment_target: Arc<T>,
) -> Result<(), Box<dyn Error>>
Registers RPC endpoints for managing a deployment target via Eclipse Symphony’s uProtocol Target Provider.

This function registers three RPC endpoints that delegate to the provided DeploymentTarget implementation:

  • Get (resource ID 0x0001) - Retrieves current component status
  • Update (resource ID 0x0002) - Updates deployment components
  • Delete (resource ID 0x0003) - Removes deployment components

Arguments

  • rpc_server - The RPC server to register the endpoints on
  • deployment_target - The deployment target implementation to delegate requests to

Errors

Returns an error if any of the endpoints cannot be registered on the RPC server.